/*
 * server.c -- a stream socket server demo
 */
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <sys/wait.h>

#define MYPORT 3490    /* the port users will be connecting to */

#define BACKLOG 10     /* how many pending connections queue will hold */

int main (void)
{
  struct sockaddr_in my_addr;    /* my address information */
  struct sockaddr_in their_addr; /* connector's address information */
  int    sockfd, new_fd;  /* listen on sock_fd, new connection on new_fd */
  int    sin_size;

  if ((sockfd = socket(AF_INET, SOCK_STREAM, 0)) == -1)
  {
    perror ("socket");
    return (1);
  }

  my_addr.sin_family = AF_INET;         /* host byte order */
  my_addr.sin_port = htons(MYPORT);     /* short, network byte order */
  my_addr.sin_addr.s_addr = INADDR_ANY; /* automatically fill with my IP */
  memset (&my_addr.sin_zero,0,8);       /* zero the rest of the struct */

  if (bind(sockfd, (struct sockaddr *)&my_addr, sizeof(struct sockaddr)) == -1)
  {
    perror ("bind");
    return (1);
  }

  if (listen(sockfd, BACKLOG) == -1)
  {
    perror ("listen");
    return (1);
  }

  while(1)   /* main accept() loop */
  {
    sin_size = sizeof (struct sockaddr_in);
    new_fd   = accept (sockfd, (struct sockaddr*)&their_addr, &sin_size);
    if (new_fd == -1)
    {
      perror ("accept");
      continue;
    }
    printf ("server: got connection from %s\n",inet_ntoa(their_addr.sin_addr));

    if (!fork())  /* this is the child process */
    {
      if (send(new_fd, "Hello, world!\n", 14, 0) == -1)
          perror ("send");
      close (new_fd);
      return (0);
    }
    close (new_fd);  /* parent doesn't need this */

    while (waitpid(-1,NULL,WNOHANG) > 0); /* clean up all child processes */
  }
  return (0);
}

