
Doug Jost <dougj@sw.ods.com> writes:
> When noncontiguous subnet bits are used, I believe
> my algorithm is no longer valid.  The subnet mask
> 255.255.88.0, is an example of a subnet mask that
> uses noncontiguous subnet bits.
> 
> Are there any books/references that explain how to
> assign subnetwork ids and host addresses when a
> noncontiguous subnet mask is used ?

Here's a simple function that increments one subnet number to the next
one, even if the mask is non-contiguous:

        u_long
        next_subnet(u_long subnet, u_long mask)
        {
            u_long bitmask;
            int bitnum;
        
            bitmask = 1;
            for (bitnum = 0; bitnum < 32; bitnum++, bitmask <<= 1)
                if (mask & bitmask)
                    if (subnet & bitmask)
                        subnet &= ~bitmask;
                    else {
                        subnet |= bitmask;
                        break;
                    }
            return subnet;
        }

If you want to increment the host number instead, then just invert the
bitmask before entering the function.

> RFC 950 states noncontiguous subnet bits are
> permitted, but thats about all it says.

They're really no longer supported by anyone.  Why would you *want* to
do this?  It provides no benefits at all.  You still end up with some
number of bits set, and some number cleared.

-- 
James Carlson, Consulting S/W Engineer  <carlson@ironbridgenetworks.com>
IronBridge Networks / 55 Hayden Avenue  71.246W    Vox:  +1 781 372 8132
Lexington MA  02421-7996 / USA          42.423N    Fax:  +1 781 372 8190
"PPP Design and Debugging" --- http://people.ne.mediaone.net/carlson/ppp
